@@ -17,13 +17,13 @@
 #include "../core/annotations.h"
 #include "../core/form.h"
 #include "../core/page.h"
-#include "../part.h"
+#include "../part/pageview.h"
+#include "../part/part.h"
+#include "../part/presentationwidget.h"
+#include "../part/sidebar.h"
+#include "../part/toc.h"
+#include "../part/toggleactionmenu.h"
 #include "../settings.h"
-#include "../ui/pageview.h"
-#include "../ui/presentationwidget.h"
-#include "../ui/sidebar.h"
-#include "../ui/toc.h"
-#include "../ui/toggleactionmenu.h"
 #include "closedialoghelper.h"
 
 #include "../generators/poppler/config-okular-poppler.h"
