@@ -10,47 +10,41 @@
 // local includes
 #include "fontinfo.h"
 
-#include <qvariant.h>
+#include <QVariant>
 
 using namespace Okular;
 
-class Okular::FontInfoPrivate
-    : public QSharedData
+class Okular::FontInfoPrivate : public QSharedData
 {
-    public:
-        FontInfoPrivate()
-          : type( FontInfo::Unknown ), embedType( FontInfo::NotEmbedded ),
-            canBeExtracted( false )
-        {
-        }
+public:
+    FontInfoPrivate()
+        : type(FontInfo::Unknown)
+        , embedType(FontInfo::NotEmbedded)
+        , canBeExtracted(false)
+    {
+    }
 
-        bool operator==( const FontInfoPrivate &rhs ) const
-        {
-            return name == rhs.name &&
-                   substituteName == rhs.substituteName &&
-                   type == rhs.type &&
-                   embedType == rhs.embedType &&
-                   file == rhs.file &&
-                   canBeExtracted == rhs.canBeExtracted;
-        }
+    bool operator==(const FontInfoPrivate &rhs) const
+    {
+        return name == rhs.name && substituteName == rhs.substituteName && type == rhs.type && embedType == rhs.embedType && file == rhs.file && canBeExtracted == rhs.canBeExtracted;
+    }
 
-        QString name;
-        QString substituteName;
-        FontInfo::FontType type;
-        FontInfo::EmbedType embedType;
-        bool canBeExtracted;
-        QString file;
-        QVariant nativeId;
+    QString name;
+    QString substituteName;
+    FontInfo::FontType type;
+    FontInfo::EmbedType embedType;
+    bool canBeExtracted;
+    QString file;
+    QVariant nativeId;
 };
 
-
 FontInfo::FontInfo()
-    : d( new FontInfoPrivate )
+    : d(new FontInfoPrivate)
 {
 }
 
-FontInfo::FontInfo( const FontInfo &fi )
-    : d( fi.d )
+FontInfo::FontInfo(const FontInfo &fi)
+    : d(fi.d)
 {
 }
 
@@ -63,7 +57,7 @@ QString FontInfo::name() const
     return d->name;
 }
 
-void FontInfo::setName( const QString& name )
+void FontInfo::setName(const QString &name)
 {
     d->name = name;
 }
@@ -73,7 +67,7 @@ QString FontInfo::substituteName() const
     return d->substituteName;
 }
 
-void FontInfo::setSubstituteName( const QString& substituteName )
+void FontInfo::setSubstituteName(const QString &substituteName)
 {
     d->substituteName = substituteName;
 }
@@ -83,7 +77,7 @@ FontInfo::FontType FontInfo::type() const
     return d->type;
 }
 
-void FontInfo::setType( FontInfo::FontType type )
+void FontInfo::setType(FontInfo::FontType type)
 {
     d->type = type;
 }
@@ -93,7 +87,7 @@ FontInfo::EmbedType FontInfo::embedType() const
     return d->embedType;
 }
 
-void FontInfo::setEmbedType( FontInfo::EmbedType type )
+void FontInfo::setEmbedType(FontInfo::EmbedType type)
 {
     d->embedType = type;
 }
@@ -103,7 +97,7 @@ QString FontInfo::file() const
     return d->file;
 }
 
-void FontInfo::setFile( const QString& file )
+void FontInfo::setFile(const QString &file)
 {
     d->file = file;
 }
@@ -118,7 +112,7 @@ void FontInfo::setCanBeExtracted(bool extractable)
     d->canBeExtracted = extractable;
 }
 
-void FontInfo::setNativeId( const QVariant &id )
+void FontInfo::setNativeId(const QVariant &id)
 {
     d->nativeId = id;
 }
@@ -128,22 +122,21 @@ QVariant FontInfo::nativeId() const
     return d->nativeId;
 }
 
-bool FontInfo::operator==( const FontInfo &fi ) const
+bool FontInfo::operator==(const FontInfo &fi) const
 {
     return *d == *fi.d;
 }
 
-bool FontInfo::operator!=( const FontInfo &fi ) const
+bool FontInfo::operator!=(const FontInfo &fi) const
 {
-    return !operator==( fi );
+    return !operator==(fi);
 }
 
-FontInfo& FontInfo::operator=( const FontInfo &fi )
+FontInfo &FontInfo::operator=(const FontInfo &fi)
 {
-    if ( this == &fi )
+    if (this == &fi)
         return *this;
 
     d = fi.d;
     return *this;
 }
-
