@@ -9,17 +9,17 @@
 
 #include "document.h"
 
-#include <QScopedPointer>
 #include <QImage>
 #include <QImageReader>
+#include <QScopedPointer>
 
 #include <KLocalizedString>
-#include <QMimeType>
+#include <KTar>
 #include <QMimeDatabase>
+#include <QMimeType>
 #include <kzip.h>
-#include <ktar.h>
 #if WITH_K7ZIP
-#include <k7zip.h>
+#include <K7Zip>
 #endif
 
 #include <memory>
@@ -33,22 +33,23 @@
 
 using namespace ComicBook;
 
-static void imagesInArchive( const QString &prefix, const KArchiveDirectory* dir, QStringList *entries )
+static void imagesInArchive(const QString &prefix, const KArchiveDirectory *dir, QStringList *entries)
 {
-    const QStringList entryList =  dir->entries();
-    for ( const QString &file : entryList ) {
-        const KArchiveEntry *e = dir->entry( file );
-        if ( e->isDirectory() ) {
-            imagesInArchive( prefix + file + QLatin1Char('/'), static_cast<const KArchiveDirectory*>( e ), entries );
-        } else if ( e->isFile() ) {
-            entries->append( prefix + file );
+    const QStringList entryList = dir->entries();
+    for (const QString &file : entryList) {
+        const KArchiveEntry *e = dir->entry(file);
+        if (e->isDirectory()) {
+            imagesInArchive(prefix + file + QLatin1Char('/'), static_cast<const KArchiveDirectory *>(e), entries);
+        } else if (e->isFile()) {
+            entries->append(prefix + file);
         }
     }
 }
 
-
 Document::Document()
-    : mDirectory( nullptr ), mUnrar( nullptr ), mArchive( nullptr )
+    : mDirectory(nullptr)
+    , mUnrar(nullptr)
+    , mArchive(nullptr)
 {
 }
 
@@ -56,7 +57,7 @@ Document::~Document()
 {
 }
 
-bool Document::open( const QString &fileName )
+bool Document::open(const QString &fileName)
 {
     close();
 
@@ -66,41 +67,40 @@ bool Document::open( const QString &fileName )
     /**
      * We have a zip archive
      */
-    if ( mime.inherits(QStringLiteral("application/x-cbz") ) || mime.inherits( QStringLiteral("application/zip") ) ) {
-        mArchive = new KZip( fileName );
+    if (mime.inherits(QStringLiteral("application/x-cbz")) || mime.inherits(QStringLiteral("application/zip"))) {
+        mArchive = new KZip(fileName);
 
-        if ( !processArchive() ) {
+        if (!processArchive()) {
             return false;
         }
-    /**
-     * We have a TAR archive
-     */
-    } else if ( mime.inherits( QStringLiteral("application/x-cbt") ) || mime.inherits( QStringLiteral("application/x-gzip") ) ||
-                mime.inherits( QStringLiteral("application/x-tar") ) || mime.inherits( QStringLiteral("application/x-bzip") ) ) {
-        mArchive = new KTar( fileName );
+        /**
+         * We have a TAR archive
+         */
+    } else if (mime.inherits(QStringLiteral("application/x-cbt")) || mime.inherits(QStringLiteral("application/x-gzip")) || mime.inherits(QStringLiteral("application/x-tar")) || mime.inherits(QStringLiteral("application/x-bzip"))) {
+        mArchive = new KTar(fileName);
 
-        if ( !processArchive() ) {
+        if (!processArchive()) {
             return false;
         }
 #ifdef WITH_K7ZIP
-    /**
-     * We have a 7z archive
-     */
-    } else if ( mime.inherits( QStringLiteral("application/x-cb7") ) || mime.inherits( QStringLiteral("application/x-7z-compressed") ) ) {
-        mArchive = new K7Zip( fileName );
+        /**
+         * We have a 7z archive
+         */
+    } else if (mime.inherits(QStringLiteral("application/x-cb7")) || mime.inherits(QStringLiteral("application/x-7z-compressed"))) {
+        mArchive = new K7Zip(fileName);
 
-        if ( !processArchive() ) {
+        if (!processArchive()) {
             return false;
         }
 #endif
-    } else if ( mime.inherits( QStringLiteral("application/x-cbr") ) || mime.inherits( QStringLiteral("application/x-rar") ) || mime.inherits( QStringLiteral("application/vnd.rar") ) ) {
-        if ( !Unrar::isAvailable() ) {
-            mLastErrorString = i18n( "Cannot open document, neither unrar nor unarchiver were found." );
+    } else if (mime.inherits(QStringLiteral("application/x-cbr")) || mime.inherits(QStringLiteral("application/x-rar")) || mime.inherits(QStringLiteral("application/vnd.rar"))) {
+        if (!Unrar::isAvailable()) {
+            mLastErrorString = i18n("Cannot open document, neither unrar nor unarchiver were found.");
             return false;
         }
 
-        if ( !Unrar::isSuitableVersionAvailable() ) {
-            mLastErrorString = i18n( "The version of unrar on your system is not suitable for opening comicbooks." );
+        if (!Unrar::isSuitableVersionAvailable()) {
+            mLastErrorString = i18n("The version of unrar on your system is not suitable for opening comicbooks.");
             return false;
         }
 
@@ -109,7 +109,7 @@ bool Document::open( const QString &fileName )
          */
         mUnrar = new Unrar();
 
-        if ( !mUnrar->open( fileName ) ) {
+        if (!mUnrar->open(fileName)) {
             delete mUnrar;
             mUnrar = nullptr;
 
@@ -117,10 +117,10 @@ bool Document::open( const QString &fileName )
         }
 
         mEntries = mUnrar->list();
-    } else if ( mime.inherits( QStringLiteral("inode/directory") ) ) {
+    } else if (mime.inherits(QStringLiteral("inode/directory"))) {
         mDirectory = new Directory();
 
-        if ( !mDirectory->open( fileName ) ) {
+        if (!mDirectory->open(fileName)) {
             delete mDirectory;
             mDirectory = nullptr;
 
@@ -129,7 +129,7 @@ bool Document::open( const QString &fileName )
 
         mEntries = mDirectory->list();
     } else {
-        mLastErrorString = i18n( "Unknown ComicBook format." );
+        mLastErrorString = i18n("Unknown ComicBook format.");
         return false;
     }
 
@@ -140,7 +140,7 @@ void Document::close()
 {
     mLastErrorString.clear();
 
-    if ( !( mArchive || mUnrar || mDirectory ) )
+    if (!(mArchive || mUnrar || mDirectory))
         return;
 
     delete mArchive;
@@ -153,8 +153,9 @@ void Document::close()
     mEntries.clear();
 }
 
-bool Document::processArchive() {
-    if ( !mArchive->open( QIODevice::ReadOnly ) ) {
+bool Document::processArchive()
+{
+    if (!mArchive->open(QIODevice::ReadOnly)) {
         delete mArchive;
         mArchive = nullptr;
 
@@ -162,7 +163,7 @@ bool Document::processArchive() {
     }
 
     const KArchiveDirectory *directory = mArchive->directory();
-    if ( !directory ) {
+    if (!directory) {
         delete mArchive;
         mArchive = nullptr;
 
@@ -171,48 +172,47 @@ bool Document::processArchive() {
 
     mArchiveDir = directory;
 
-    imagesInArchive( QString(), mArchiveDir, &mEntries );
+    imagesInArchive(QString(), mArchiveDir, &mEntries);
 
     return true;
 }
 
-void Document::pages( QVector<Okular::Page*> * pagesVector )
+void Document::pages(QVector<Okular::Page *> *pagesVector)
 {
     std::sort(mEntries.begin(), mEntries.end(), caseSensitiveNaturalOrderLessThen);
-    QScopedPointer< QIODevice > dev;
+    QScopedPointer<QIODevice> dev;
 
     int count = 0;
     pagesVector->clear();
-    pagesVector->resize( mEntries.size() );
+    pagesVector->resize(mEntries.size());
     QImageReader reader;
-    reader.setAutoTransform( true );
+    reader.setAutoTransform(true);
     for (const QString &file : qAsConst(mEntries)) {
-        if ( mArchive ) {
-            const KArchiveFile *entry = static_cast<const KArchiveFile*>( mArchiveDir->entry( file ) );
-            if ( entry ) {
-                dev.reset( entry->createDevice() );
+        if (mArchive) {
+            const KArchiveFile *entry = static_cast<const KArchiveFile *>(mArchiveDir->entry(file));
+            if (entry) {
+                dev.reset(entry->createDevice());
             }
-        } else if ( mDirectory ) {
-            dev.reset( mDirectory->createDevice( file ) );
+        } else if (mDirectory) {
+            dev.reset(mDirectory->createDevice(file));
         } else {
-            dev.reset( mUnrar->createDevice( file ) );
+            dev.reset(mUnrar->createDevice(file));
         }
 
-        if ( ! dev.isNull() ) {
-            reader.setDevice( dev.data() );
-            if ( reader.canRead() )
-            {
+        if (!dev.isNull()) {
+            reader.setDevice(dev.data());
+            if (reader.canRead()) {
                 QSize pageSize = reader.size();
                 if (reader.transformation() & QImageIOHandler::TransformationRotate90) {
                     pageSize.transpose();
                 }
-                if ( !pageSize.isValid() ) {
+                if (!pageSize.isValid()) {
                     const QImage i = reader.read();
-                    if ( !i.isNull() )
+                    if (!i.isNull())
                         pageSize = i.size();
                 }
-                if ( pageSize.isValid() ) {
-                    pagesVector->replace( count, new Okular::Page( count, pageSize.width(), pageSize.height(), Okular::Rotation0 ) );
+                if (pageSize.isValid()) {
+                    pagesVector->replace(count, new Okular::Page(count, pageSize.width(), pageSize.height(), Okular::Rotation0));
                     mPageMap.append(file);
                     count++;
                 } else {
@@ -221,7 +221,7 @@ void Document::pages( QVector<Okular::Page*> * pagesVector )
             }
         }
     }
-    pagesVector->resize( count );
+    pagesVector->resize(count);
 }
 
 QStringList Document::pageTitles() const
@@ -229,20 +229,20 @@ QStringList Document::pageTitles() const
     return QStringList();
 }
 
-QImage Document::pageImage( int page ) const
+QImage Document::pageImage(int page) const
 {
-    if ( mArchive ) {
-        const KArchiveFile *entry = static_cast<const KArchiveFile*>( mArchiveDir->entry( mPageMap[ page ] ) );
-        if ( entry ) {
+    if (mArchive) {
+        const KArchiveFile *entry = static_cast<const KArchiveFile *>(mArchiveDir->entry(mPageMap[page]));
+        if (entry) {
             std::unique_ptr<QIODevice> dev(entry->createDevice());
-            QImageReader reader( dev.get() );
-            reader.setAutoTransform( true );
+            QImageReader reader(dev.get());
+            reader.setAutoTransform(true);
             return reader.read();
         }
-    } else if ( mDirectory ) {
-        return QImage( mPageMap[ page ] );
+    } else if (mDirectory) {
+        return QImage(mPageMap[page]);
     } else {
-        return QImage::fromData( mUnrar->contentOf( mPageMap[ page ] ) );
+        return QImage::fromData(mUnrar->contentOf(mPageMap[page]));
     }
 
     return QImage();
