@@ -10,33 +10,32 @@
 #ifndef EPUB_CONVERTER_H
 #define EPUB_CONVERTER_H
 
-#include <core/textdocumentgenerator.h>
 #include <core/document.h>
+#include <core/textdocumentgenerator.h>
 
 #include "epubdocument.h"
 
-
-namespace Epub {
-  class Converter : public Okular::TextDocumentConverter
-  {
+namespace Epub
+{
+class Converter : public Okular::TextDocumentConverter
+{
     Q_OBJECT
 
-    public:
-      Converter();
-      ~Converter() override;
+public:
+    Converter();
+    ~Converter() override;
 
-      QTextDocument *convert( const QString &fileName ) override;
+    QTextDocument *convert(const QString &fileName) override;
 
-    private:
+private:
+    void _emitData(Okular::DocumentInfo::Key key, enum epub_metadata type);
+    void _handle_anchors(const QTextBlock &start, const QString &name);
+    void _insert_local_links(const QString &key, const QPair<int, int> value);
+    EpubDocument *mTextDocument;
 
-      void _emitData(Okular::DocumentInfo::Key key, enum epub_metadata type); 
-      void _handle_anchors(const QTextBlock &start, const QString &name);
-      void _insert_local_links(const QString &key, const QPair<int, int> value);
-      EpubDocument *mTextDocument;
-
-      QHash<QString, QTextBlock> mSectionMap;
-      QHash<QString, QVector< QPair<int, int> > > mLocalLinks;
-    };
+    QHash<QString, QTextBlock> mSectionMap;
+    QHash<QString, QVector<QPair<int, int>>> mLocalLinks;
+};
 }
 
 #endif
