@@ -12,13 +12,13 @@
 #include "converter.h"
 
 #include <KAboutData>
-#include <kconfigdialog.h>
+#include <KConfigDialog>
 #include <KLocalizedString>
 
 OKULAR_EXPORT_PLUGIN(EPubGenerator, "libokularGenerator_epub.json")
 
-EPubGenerator::EPubGenerator( QObject *parent, const QVariantList &args )
-: Okular::TextDocumentGenerator(new Epub::Converter, QStringLiteral("okular_epub_generator_settings"), parent, args)
+EPubGenerator::EPubGenerator(QObject *parent, const QVariantList &args)
+    : Okular::TextDocumentGenerator(new Epub::Converter, QStringLiteral("okular_epub_generator_settings"), parent, args)
 {
 }
 
@@ -26,11 +26,11 @@ EPubGenerator::~EPubGenerator()
 {
 }
 
-void EPubGenerator::addPages( KConfigDialog* dlg )
+void EPubGenerator::addPages(KConfigDialog *dlg)
 {
-  Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
+    Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-  dlg->addPage( widget, generalSettings(), i18n("EPub"), QStringLiteral("application-epub+zip"), i18n("EPub Backend Configuration") );
+    dlg->addPage(widget, generalSettings(), i18n("EPub"), QStringLiteral("application-epub+zip"), i18n("EPub Backend Configuration"));
 }
 
 #include "generator_epub.moc"
