@@ -12,21 +12,20 @@
 #include "converter.h"
 
 #include <KAboutData>
+#include <KConfigDialog>
 #include <KLocalizedString>
-#include <kconfigdialog.h>
 
 OKULAR_EXPORT_PLUGIN(FictionBookGenerator, "libokularGenerator_fb.json")
 
-FictionBookGenerator::FictionBookGenerator( QObject *parent, const QVariantList &args )
-    : Okular::TextDocumentGenerator( new FictionBook::Converter, QStringLiteral("okular_fictionbook_generator_settings"), parent, args )
+FictionBookGenerator::FictionBookGenerator(QObject *parent, const QVariantList &args)
+    : Okular::TextDocumentGenerator(new FictionBook::Converter, QStringLiteral("okular_fictionbook_generator_settings"), parent, args)
 {
 }
 
-void FictionBookGenerator::addPages( KConfigDialog* dlg )
+void FictionBookGenerator::addPages(KConfigDialog *dlg)
 {
     Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-    dlg->addPage( widget, generalSettings(), i18n("FictionBook"), QStringLiteral("okular-fb2"), i18n("FictionBook Backend Configuration") );
+    dlg->addPage(widget, generalSettings(), i18n("FictionBook"), QStringLiteral("okular-fb2"), i18n("FictionBook Backend Configuration"));
 }
 #include "generator_fb.moc"
-
