@@ -9,10 +9,10 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-#ifndef OKULAR_MD_DEBUG_P_H
-#define OKULAR_MD_DEBUG_P_H
+#ifndef OKULAR_DEBUG_MD_H
+#define OKULAR_DEBUG_MD_H
 
-#include <QtCore/qloggingcategory.h>
+#include <QLoggingCategory>
 
 Q_DECLARE_LOGGING_CATEGORY(OkularMdDebug)
 
