@@ -11,21 +11,21 @@
 #include "converter.h"
 
 #include <KAboutData>
-#include <kconfigdialog.h>
+#include <KConfigDialog>
 #include <KLocalizedString>
 
 OKULAR_EXPORT_PLUGIN(MobiGenerator, "libokularGenerator_mobi.json")
 
-MobiGenerator::MobiGenerator( QObject *parent, const QVariantList &args )
-: Okular::TextDocumentGenerator( new Mobi::Converter, QStringLiteral("okular_mobi_generator_settings"), parent, args )
+MobiGenerator::MobiGenerator(QObject *parent, const QVariantList &args)
+    : Okular::TextDocumentGenerator(new Mobi::Converter, QStringLiteral("okular_mobi_generator_settings"), parent, args)
 {
 }
 
-void MobiGenerator::addPages( KConfigDialog* dlg )
+void MobiGenerator::addPages(KConfigDialog *dlg)
 {
     Okular::TextDocumentSettingsWidget *widget = new Okular::TextDocumentSettingsWidget();
 
-    dlg->addPage( widget, generalSettings(), i18n("Mobipocket"), QStringLiteral("application-x-mobipocket-ebook"), i18n("Mobipocket Backend Configuration") );
+    dlg->addPage(widget, generalSettings(), i18n("Mobipocket"), QStringLiteral("application-x-mobipocket-ebook"), i18n("Mobipocket Backend Configuration"));
 }
 
 #include "generator_mobi.moc"
