@@ -17,10 +17,7 @@
 
 #include <poppler-qt5.h>
 
-#include <config-okular-poppler.h>
-
 extern Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLink, bool deletePopplerLink = true);
-#ifdef HAVE_POPPLER_0_65
 #define SET_ANNOT_ACTIONS                                                                                                                                                                                                                      \
     setAdditionalAction(Okular::Annotation::CursorEntering, createLinkFromPopplerLink(m_field->additionalAction(Poppler::Annotation::CursorEnteringAction)));                                                                                  \
     setAdditionalAction(Okular::Annotation::CursorLeaving, createLinkFromPopplerLink(m_field->additionalAction(Poppler::Annotation::CursorLeavingAction)));                                                                                    \
@@ -28,9 +25,6 @@ extern Okular::Action *createLinkFromPopplerLink(const Poppler::Link *popplerLin
     setAdditionalAction(Okular::Annotation::MouseReleased, createLinkFromPopplerLink(m_field->additionalAction(Poppler::Annotation::MouseReleasedAction)));                                                                                    \
     setAdditionalAction(Okular::Annotation::FocusIn, createLinkFromPopplerLink(m_field->additionalAction(Poppler::Annotation::FocusInAction)));                                                                                                \
     setAdditionalAction(Okular::Annotation::FocusOut, createLinkFromPopplerLink(m_field->additionalAction(Poppler::Annotation::FocusOutAction)));
-#else
-#define SET_ANNOT_ACTIONS
-#endif
 
 #define SET_ACTIONS                                                                                                                                                                                                                            \
     setActivationAction(createLinkFromPopplerLink(m_field->activationAction()));                                                                                                                                                               \
@@ -81,11 +75,7 @@ bool PopplerFormFieldButton::isReadOnly() const
 
 void PopplerFormFieldButton::setReadOnly(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setReadOnly(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldButton::isVisible() const
@@ -95,29 +85,17 @@ bool PopplerFormFieldButton::isVisible() const
 
 void PopplerFormFieldButton::setVisible(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setVisible(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldButton::isPrintable() const
 {
-#ifdef HAVE_POPPLER_0_79
     return m_field->isPrintable();
-#else
-    return true;
-#endif
 }
 
 void PopplerFormFieldButton::setPrintable(bool value)
 {
-#ifdef HAVE_POPPLER_0_79
     m_field->setPrintable(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 Okular::FormFieldButton::ButtonType PopplerFormFieldButton::buttonType() const
@@ -153,23 +131,17 @@ QList<int> PopplerFormFieldButton::siblings() const
     return m_field->siblings();
 }
 
-#ifdef HAVE_POPPLER_0_79
 Poppler::FormFieldIcon PopplerFormFieldButton::icon() const
 {
     return m_field->icon();
 }
-#endif
 
 void PopplerFormFieldButton::setIcon(Okular::FormField *field)
 {
-#ifdef HAVE_POPPLER_0_79
     if (field->type() == Okular::FormField::FormButton) {
         PopplerFormFieldButton *button = static_cast<PopplerFormFieldButton *>(field);
         m_field->setIcon(button->icon());
     }
-#else
-    Q_UNUSED(field);
-#endif
 }
 
 PopplerFormFieldText::PopplerFormFieldText(std::unique_ptr<Poppler::FormFieldText> field)
@@ -213,11 +185,7 @@ bool PopplerFormFieldText::isReadOnly() const
 
 void PopplerFormFieldText::setReadOnly(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setReadOnly(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldText::isVisible() const
@@ -227,29 +195,17 @@ bool PopplerFormFieldText::isVisible() const
 
 void PopplerFormFieldText::setVisible(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setVisible(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldText::isPrintable() const
 {
-#ifdef HAVE_POPPLER_0_79
     return m_field->isPrintable();
-#else
-    return true;
-#endif
 }
 
 void PopplerFormFieldText::setPrintable(bool value)
 {
-#ifdef HAVE_POPPLER_0_79
     m_field->setPrintable(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 Okular::FormFieldText::TextType PopplerFormFieldText::textType() const
@@ -277,11 +233,7 @@ void PopplerFormFieldText::setText(const QString &text)
 
 void PopplerFormFieldText::setAppearanceText(const QString &text)
 {
-#ifdef HAVE_POPPLER_0_80
     m_field->setAppearanceText(text);
-#else
-    Q_UNUSED(text);
-#endif
 }
 
 bool PopplerFormFieldText::isPassword() const
@@ -359,11 +311,7 @@ bool PopplerFormFieldChoice::isReadOnly() const
 
 void PopplerFormFieldChoice::setReadOnly(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setReadOnly(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldChoice::isVisible() const
@@ -373,29 +321,17 @@ bool PopplerFormFieldChoice::isVisible() const
 
 void PopplerFormFieldChoice::setVisible(bool value)
 {
-#ifdef HAVE_POPPLER_0_64
     m_field->setVisible(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 bool PopplerFormFieldChoice::isPrintable() const
 {
-#ifdef HAVE_POPPLER_0_79
     return m_field->isPrintable();
-#else
-    return true;
-#endif
 }
 
 void PopplerFormFieldChoice::setPrintable(bool value)
 {
-#ifdef HAVE_POPPLER_0_79
     m_field->setPrintable(value);
-#else
-    Q_UNUSED(value);
-#endif
 }
 
 Okular::FormFieldChoice::ChoiceType PopplerFormFieldChoice::choiceType() const
