@@ -9,7 +9,7 @@
 
 #include "rendererthread.h"
 
-#include <qimage.h>
+#include <QImage>
 
 #include "spectre_debug.h"
 
@@ -21,7 +21,8 @@ GSRendererThread *GSRendererThread::theRenderer = nullptr;
 
 GSRendererThread *GSRendererThread::getCreateRenderer()
 {
-    if (!theRenderer) theRenderer = new GSRendererThread();
+    if (!theRenderer)
+        theRenderer = new GSRendererThread();
     return theRenderer;
 }
 
@@ -45,8 +46,7 @@ void GSRendererThread::addRequest(const GSRendererThreadRequest &req)
 
 void GSRendererThread::run()
 {
-    while(true)
-    {
+    while (true) {
         m_semaphore.acquire();
         {
             m_queueMutex.lock();
@@ -65,63 +65,54 @@ void GSRendererThread::run()
             int wantedWidth = req.request->width();
             int wantedHeight = req.request->height();
 
-            if ( req.orientation % 2 )
-                qSwap( wantedWidth, wantedHeight );
+            if (req.orientation % 2)
+                qSwap(wantedWidth, wantedHeight);
 
             spectre_page_render(req.spectrePage, m_renderContext, &data, &row_length);
 
             // Qt needs the missing alpha of QImage::Format_RGB32 to be 0xff
-            if (data && data[3] != 0xff)
-            {
+            if (data && data[3] != 0xff) {
                 for (int i = 3; i < row_length * wantedHeight; i += 4)
                     data[i] = 0xff;
             }
 
             QImage img;
-            if (row_length == wantedWidth * 4)
-            {
+            if (row_length == wantedWidth * 4) {
                 img = QImage(data, wantedWidth, wantedHeight, QImage::Format_RGB32);
-            }
-            else
-            {
+            } else {
                 // In case this ends up beign very slow we can try with some memmove
                 QImage aux(data, row_length / 4, wantedHeight, QImage::Format_RGB32);
                 img = QImage(aux.copy(0, 0, wantedWidth, wantedHeight));
             }
 
-            switch (req.orientation)
-            {
-                case Okular::Rotation90:
-                {
-                    QTransform m;
-                    m.rotate(90);
-                    img = img.transformed( m );
-                    break;
-                }
+            switch (req.orientation) {
+            case Okular::Rotation90: {
+                QTransform m;
+                m.rotate(90);
+                img = img.transformed(m);
+                break;
+            }
 
-                case Okular::Rotation180:
-                {
-                    QTransform m;
-                    m.rotate(180);
-                    img = img.transformed( m );
-                    break;
-                }
-                case Okular::Rotation270:
-                {
-                    QTransform m;
-                    m.rotate(270);
-                    img = img.transformed( m );
-                }
+            case Okular::Rotation180: {
+                QTransform m;
+                m.rotate(180);
+                img = img.transformed(m);
+                break;
+            }
+            case Okular::Rotation270: {
+                QTransform m;
+                m.rotate(270);
+                img = img.transformed(m);
+            }
             }
 
             QImage *image = new QImage(img.copy());
             free(data);
 
-            if (image->width() != req.request->width() || image->height() != req.request->height())
-            {
+            if (image->width() != req.request->width() || image->height() != req.request->height()) {
                 qCWarning(OkularSpectreDebug).nospace() << "Generated image does not match wanted size: "
-                    << "[" << image->width() << "x" << image->height() << "] vs requested "
-                    << "[" << req.request->width() << "x" << req.request->height() << "]";
+                                                        << "[" << image->width() << "x" << image->height() << "] vs requested "
+                                                        << "[" << req.request->width() << "x" << req.request->height() << "]";
                 QImage aux = image->scaled(wantedWidth, wantedHeight);
                 delete image;
                 image = new QImage(aux);
