@@ -7,23 +7,23 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
-
 #ifndef _GENERATOR_TXT_H_
 #define _GENERATOR_TXT_H_
 
-
 #include <core/textdocumentgenerator.h>
 
 class TxtGenerator : public Okular::TextDocumentGenerator
 {
     Q_OBJECT
-    Q_INTERFACES( Okular::Generator )
+    Q_INTERFACES(Okular::Generator)
 
 public:
     TxtGenerator(QObject *parent, const QVariantList &args);
-    ~TxtGenerator() override {}
+    ~TxtGenerator() override
+    {
+    }
 
-    void addPages( KConfigDialog* dlg ) override;
+    void addPages(KConfigDialog *dlg) override;
 };
 
 #endif
